function p = RaisedCos(t, Tsym, rolloff);
% function p = RaisedCos(t,Tsym, rolloff)
%   Raised cosine filter

% Inputs:
%   t: discrete time vector (seconds)
%   Tsym: Symbol interval in seconds
%   rolloff: rolloff factor, default is 0.35
%
% Outputs:
%   p : filter impulse response;
 

if nargin == 2
    rolloff = 0.35; % default rolloff factor 
end

test=0; %test the function if set to 1
if test==1
    Tau=Tsym/10; % multipath delay
    Delay=floor(Tau/Tsym);
    N_up=5; % upsampling rate
    Ts=Tsym/N_up;% sampling interval
    FilterLength=6;
    Ns=FilterLength*N_up;
    t=[-Ns:Ns]*Ts - (Tau-Delay*Tsym);
end

normal = (t~=0);
t_normal = pi*t(normal)/Tsym;
p(normal) = sin(t_normal)./t_normal.*cos(rolloff*t_normal)./(1-4*rolloff^2*t_normal.^2/pi^2);
excep = (t==0);
p(excep) = 1;

