function Gt=RayleighFlat(Ns, Ts, Fd);

%Function gt=RayleighFlat(Ns, Ts, Fd)
% Generate base band equivalent complex channel impulse response for 
% frequency flat Rayleigh fading channels using Sum-of-Sinusoids method
% reference: Zheng and Xiao, IEEE Communication Letters 2002

% Inputs:
%    Ns : number of samples in the generated fading impulse response
%    Ts : Sampling Interval in seconds
%    Fd : Maxmimum Doppler Frequency in Hz

% Output:
%   Gt : complex channel impulse response

% Useage: 
%   Gt=RayleighFlat(2e3, 1e-4, 100);
%   Rx=Tx.*Gt; 
%   where Tx is the vector of transmitted complex signal sampled at Ts and with a length Ns; 

% Created by Y. R. Zheng and C. Xiao. 
% Free for education and research. 

if nargin ~= 3
   error('Three input parameters are expected: Ns, Ts, Fd');
end


M = 16; % # of Sinusoids
n = [1:M]; %row vector


theta = (2*rand-1)*pi;
alpha = (2*pi*n-pi+theta)/(4*M); %row vector

omega_d = 2*pi*Fd;
t = [0:Ns-1]*Ts;
omega_t = omega_d*cos(alpha)'*t; % M by Ns matrix

A=sqrt(2/M)*ones(1,M); %row vector
phi = (2*rand(M,1)-1)*pi; %column vector
psi = (2*rand(M,1)-1)*pi; 
Gc = A*cos(omega_t+ phi*ones(1, Ns));
Gs = A*sin(omega_t+ psi*ones(1, Ns));

Gt = Gc + j*Gs; %row vector

