% frequency selective fading channel example
% power delay profiles from GSM standards 
% reference: ETIS Technical Specification 3GPP TS05.05, V8.20.0

% Created by Y. R. Zheng and C. Xiao. 
% Free for education and research. 

clear all
rand('state',sum(100*clock));%Initialize RAND to a different state each time.

pwr_delay_profile='tu';
switch pwr_delay_profile
case 'tu' % typical urban
    Tau= [0, 0.1, 0.3, 0.5, 0.8, 1.1, 1.3, 1.7, 2.3, 3.1, 3.2, 5]*1e-6;
    PdB= [-4, -3, 0, -2.6, -3.0, -5, -7.0, -5.0, -6.5, -8.6, -11, -10];  
    
case 'tur' % typical urban redued
    Tau = [0, 0.2, 0.5, 1.6, 2.3, 5.0]*1e-6;
    PdB= [-3.0, 0, -2.0, -6.0, -8.0, -10.0];
end

Fd=[100];% corresponding to vehicle speed=30 m/s at fc=1GHz
Ns=20000;
Tsym=3.69e-6; % GSM symbol interval
N_upsampling=2; % for fractionally-spaced equalizers
Ts=Tsym/N_upsampling;

[Httau,GroupDelay]=RayleighSelective(Ns, Ts, Fd, Tsym, Tau, PdB);
Gtt=20*log10(abs(Httau));
mesh(Gtt(GroupDelay:size(Gtt,1),:))
xlabel('t (/Ts)')
ylabel('\tau (/Ts)')
zlabel('Channel Impulse Response (dB)')